
package interfazgrafica8;

import javax.swing.JComboBox;
import javax.swing.JTextField;

public class Componentes {
      
      private JComboBox jComboBox;  
      private JTextField jTextfield;
    
    public JComboBox getjComboBox() {
        return jComboBox;
    }

    public void setjComboBox(JComboBox jComboBox) {
        this.jComboBox = jComboBox;
    }

    public JTextField getjTextfield() {
        return jTextfield;
    }

    public void setjTextfield(JTextField jTextfield) {
        this.jTextfield = jTextfield;
    }
}
