
package interfazgrafica8;

import java.awt.EventQueue;
import javax.swing.JButton;
import javax.swing.JComboBox;
import javax.swing.JFrame;
import javax.swing.JTextField;

public class InterfazGrafica8 extends JFrame {
 
    public InterfazGrafica8() {
        setSize(700,500);
        setTitle("Ejemplo utilización JComboBox");
        ubicarComponentes();
        setVisible(true);
    }
 
    private void ubicarComponentes() {

        setLayout(null);
        
        Componentes componentes = new Componentes();
        GestorEventos gestorEventos = new GestorEventos(componentes);
        
        addWindowListener(gestorEventos);        // REGISTRO DE ESCUCHA DE EVENTOS DE VENTANA
                   // CONFIGURACIÓN JComboBox
        componentes.setjComboBox(new JComboBox());
        componentes.getjComboBox().setBounds(5, 150, 250, 20);    
        componentes.getjComboBox().setActionCommand("combo");
        componentes.getjComboBox().addActionListener(gestorEventos);    // REGISTRO DE ESCUCHA DE EVENTO EN JComboBox      
        add(componentes.getjComboBox());
                   // CONFIGURACIÓN JTextField
        componentes.setjTextfield(new JTextField());
        componentes.getjTextfield().setBounds(400, 150, 200, 20);
        add(componentes.getjTextfield()); 
                   // CONFIGURACIÓN JButton jButtonAñadir
        JButton jButtonAñadir = new JButton("Añadir");
        jButtonAñadir.setBounds(285, 150, 90, 40);  
        jButtonAñadir.setActionCommand("botonAñadir");
        jButtonAñadir.addActionListener(gestorEventos);   // REGISTRO DE ESCUCHA DE EVENTO DE BOTON
        add(jButtonAñadir);
                   // CONFIGURACIÓN JButton jButtonVaciar
        JButton jButtonVaciar = new JButton("Vaciar");
        jButtonVaciar.setBounds(285, 200, 90, 40);   
        jButtonVaciar.setActionCommand("botonVaciar");
        jButtonVaciar.addActionListener(gestorEventos);   // REGISTRO DE ESCUCHA DE EVENTO DE BOTON
        add(jButtonVaciar);
                   // CONFIGURACIÓN JButton jButtonEliminar
        JButton jButtonEliminar = new JButton("Eliminar");
        jButtonEliminar.setBounds(285, 250, 90, 40);   
        jButtonEliminar.setActionCommand("botonEliminar");
        jButtonEliminar.addActionListener(gestorEventos); // REGISTRO DE ESCUCHA DE EVENTO DE BOTON
        add(jButtonEliminar);                  
    }
    
    public static void main(String[] args) {
        EventQueue.invokeLater(new Runnable() {
              @Override
              public void run() {
                 new InterfazGrafica8();
              }
           });  
    }
}
